@@ -8,8 +8,12 @@ def installed_version():
     """Return version of installed binary"""
     if not C().firefox_binary.is_file():
         return 0
-    infos = subprocess.run([C().firefox_binary, '--version'], capture_output=True, check=True)
-    match = re.search(r'\d+\.\d+', infos.stdout.decode())
+    if C().FUSER:
+        command = ["su", C().FUSER, "-c", f"{C().firefox_binary} --version"]
+    else:
+        command = [C().firefox_binary, '--version']
+    infos = subprocess.run(command, capture_output=True, check=True)
+    match = re.search(r'\d+\.\d+(\.\d+)?', infos.stdout.decode())
     if match:
         return match.group()
     return None
